==> configlinux-0.1.tar.gz: configlinux-0.1/configlinux/swlioctl.h <==
/***************************************************************************
                          swlioctl.h  -  description
                             -------------------
    begin                : Fri Jun 23 2000
    copyright            : (C) 2000 by Jae-Jun Lee
    email                : brucejr@samsung.co.kr
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

 //Private IOCTL values that are used with communicating between Utility and driver.
 #define SWL_UIL_NETWORKMODE_GET  1   //get network mode value.
 #define SWL_UIL_NETWORKMODE_SET  2   //set network mode value.
 #define SWL_UIL_PSMODE_GET       3   //get power saving mode value.
 #define SWL_UIL_PSMODE_SET       4   //set power saving mdoe value.
 #define SWL_UIL_COMMSQUALITY     5   //get communication quality values.
 #define SWL_UIL_LINKSTATUS       6   //get link status value.
 #define SWL_UIL_SOFTRESET        7   //do software reset.
 #define SWL_UIL_WEPDEFAULTKEYID_GET  8
 #define SWL_UIL_WEPDEFAULTKEYID_SET  9
 #define SWL_UIL_WEPDEFAULTKEY1   10
 #define SWL_UIL_WEPDEFAULTKEY2   11
 #define SWL_UIL_WEPDEFAULTKEY3   12
 #define SWL_UIL_WEPDEFAULTKEY4   13
 #define SWL_UIL_WEPFLAGS_GET     14
 #define SWL_UIL_WEPFLAGS_SET     15
 #define SWL_UIL_VER              16
 #define SWL_UIL_CURRENT_ADDRESS  17
 #define SWL_UIL_PROMISCUOUS_MODE 18    //set
 #define SWL_UIL_TXRATE_GET       19
 #define SWL_UIL_TXRATE_SET       20
 #define SWL_UIL_DOMAIN           21
 #define SWL_UIL_WEPKEYID_GET     22
 #define SWL_UIL_WEPKEYID_SET     23
 #define SWL_UIL_WEPKEY1          24
 #define SWL_UIL_WEPKEY2          25
 #define SWL_UIL_WEPKEY3          26
 #define SWL_UIL_WEPKEY4          27
 #define SWL_UIL_RTSCTS_GET       28
 #define SWL_UIL_RTSCTS_SET       29

 //Link Statu
 #define LINK_NOT_CONNECTED       0
 #define LINK_CONNECTED		    1
 #define LINK_DISCONNECTED        2
 #define LINK_AP_CHANGE           3
 #define LINK_AP_OUTOF_RANGE      4
 #define LINK_AP_IN_RANGE         5
 #define LINK_ASSOCIATION_FAILED  6

 //Domain
 #define ETSI 0x30     //Channel 1 ~ 13
 #define FCC  0x10     //Channel 1 ~ 11
 #define IC   0x20
 #define FRANCE 0x32   //Channel 10 ~ 13
 #define SPAIN  0x31   //Channel 10 ~ 11

==> configlinux-0.2.tar.gz: configlinux-0.2/configlinux/swlioctl.h <==
/***************************************************************************
                          swlioctl.h  -  description
                             -------------------
    begin                : Fri Jun 23 2000
    copyright            : (C) 2000 by Jae-Jun Lee
    email                : brucejr@samsung.co.kr
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

 //Private IOCTL values that are used with communicating between Utility and driver.
 #define SWL_UIL_NETWORKMODE_GET  1
 #define SWL_UIL_NETWORKMODE_SET  2
 #define SWL_UIL_PSMODE_GET       3
 #define SWL_UIL_PSMODE_SET       4
 #define SWL_UIL_COMMSQUALITY     5   //get
 #define SWL_UIL_LINKSTATUS       6
 #define SWL_UIL_SOFTRESET        7
 #define SWL_UIL_WEPDEFAULTKEYID_GET  8
 #define SWL_UIL_WEPDEFAULTKEYID_SET  9
 #define SWL_UIL_WEPDEFAULTKEY1   10
 #define SWL_UIL_WEPDEFAULTKEY2   11
 #define SWL_UIL_WEPDEFAULTKEY3   12
 #define SWL_UIL_WEPDEFAULTKEY4   13
 #define SWL_UIL_WEPFLAGS_GET     14
 #define SWL_UIL_WEPFLAGS_SET     15
 #define SWL_UIL_VER              16
 #define SWL_UIL_CURRENT_ADDRESS  17
 #define SWL_UIL_PROMISCUOUS_MODE 18    //set
 #define SWL_UIL_TXRATE_GET       19
 #define SWL_UIL_TXRATE_SET       20
 #define SWL_UIL_DOMAIN           21
 #define SWL_UIL_WEPKEYID_GET     22
 #define SWL_UIL_WEPKEYID_SET     23
 #define SWL_UIL_WEPKEY1_GET      24
 #define SWL_UIL_WEPKEY1_SET      25
 #define SWL_UIL_WEPKEY2_GET      26
 #define SWL_UIL_WEPKEY2_SET      27
 #define SWL_UIL_WEPKEY3_GET      28
 #define SWL_UIL_WEPKEY3_SET      29
 #define SWL_UIL_WEPKEY4_GET      30
 #define SWL_UIL_WEPKEY4_SET      31
 #define SWL_UIL_RTSCTS_GET       32
 #define SWL_UIL_RTSCTS_SET       33
 #define SWL_UIL_SCANRESULT       34
 #define SWL_UIL_SITESURVEY_START 35
 #define SWL_UIL_SITESURVEY_END   36
 #define SWL_UIL_SITESURVEY_CONT  37
 #define SWL_UIL_ESSID            38

 //Link Statu
 #define LINK_NOT_CONNECTED       0
 #define LINK_CONNECTED		    1
 #define LINK_DISCONNECTED        2
 #define LINK_AP_CHANGE           3
 #define LINK_AP_OUTOF_RANGE      4
 #define LINK_AP_IN_RANGE         5
 #define LINK_ASSOCIATION_FAILED  6

 //Domain
 #define ETSI 0x30     //Channel 1 ~ 13
 #define FCC  0x10     //Channel 1 ~ 11
 #define IC   0x20
 #define FRANCE 0x32   //Channel 10 ~ 13
 #define SPAIN  0x31   //Channel 10 ~ 11
